Bifrost: Data Fields - Functions

Bifrost

### - a -

- add() : CompactedDBG< Unitig_data_t, Graph_data_t > , UnitigColors

### - b -

- backwardBase() : Kmer
- BackwardCDBG() : BackwardCDBG< Unitig_data_t, Graph_data_t, is_const >
- begin() : BackwardCDBG< Unitig_data_t, Graph_data_t, is_const > , CompactedDBG< Unitig_data_t, Graph_data_t > , ForwardCDBG< Unitig_data_t, Graph_data_t, is_const > , UnitigColors
- build() : CompactedDBG< Unitig_data_t, Graph_data_t >
- buildColors() : ColoredCDBG< Unitig_data_t >
- buildGraph() : ColoredCDBG< Unitig_data_t >

### - c -

- clear() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t > , UnitigColors
- ColoredCDBG() : ColoredCDBG< Unitig_data_t >
- colorMax() : UnitigColors
- CompactedDBG() : CompactedDBG< Unitig_data_t, Graph_data_t >
- concat() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >
- contains() : UnitigColors

### - d -

- DataAccessor() : DataAccessor< Unitig_data_t >

### - e -

- end() : BackwardCDBG< Unitig_data_t, Graph_data_t, is_const > , CompactedDBG< Unitig_data_t, Graph_data_t > , ForwardCDBG< Unitig_data_t, Graph_data_t, is_const > , UnitigColors
- extract() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >

### - f -

- find() : CompactedDBG< Unitig_data_t, Graph_data_t >
- findUnitig() : CompactedDBG< Unitig_data_t, Graph_data_t >
- forwardBase() : Kmer
- ForwardCDBG() : ForwardCDBG< Unitig_data_t, Graph_data_t, is_const >

### - g -

- getChar() : Kmer
- getColorID() : UnitigColors::UnitigColors_const_iterator
- getColorName() : ColoredCDBG< Unitig_data_t >
- getColorNames() : ColoredCDBG< Unitig_data_t >
- getData() : CompactedDBG< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t > , Unitig< T > , UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getGraph() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getK() : CompactedDBG< Unitig_data_t, Graph_data_t >
- getKmerMapping() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getKmerPosition() : UnitigColors::UnitigColors_const_iterator
- getMappedHead() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getMappedKmer() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getMappedTail() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getNbColors() : ColoredCDBG< Unitig_data_t >
- getPredecessors() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getSizeInBytes() : UnitigColors
- getSubUnitigColorNames() : DataAccessor< Unitig_data_t >
- getSubUnitigColors() : DataAccessor< Unitig_data_t >
- getSuccessors() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getUnitigColors() : DataAccessor< Unitig_data_t >
- getUnitigHead() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getUnitigKmer() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getUnitigTail() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >

### - h -

- hash() : Kmer
- hasPredecessors() : BackwardCDBG< Unitig_data_t, Graph_data_t, is_const >
- hasSuccessors() : ForwardCDBG< Unitig_data_t, Graph_data_t, is_const >

### - i -

- isEmpty() : UnitigColors
- isEqual() : UnitigColors
- isInvalid() : CompactedDBG< Unitig_data_t, Graph_data_t >

### - k -

- Kmer() : Kmer

### - l -

- lcp() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- length() : CompactedDBG< Unitig_data_t, Graph_data_t >

### - m -

- mappedSequenceToString() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- merge() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >

### - n -

- neighborIterator() : neighborIterator< Unitig_data_t, Graph_data_t, is_const >
- nextColor() : UnitigColors::UnitigColors_const_iterator

### - o -

- operator!=() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , Kmer , neighborIterator< Unitig_data_t, Graph_data_t, is_const > , UnitigColors::UnitigColors_const_iterator , unitigIterator< Unitig_data_t, Graph_data_t, is_const > , UnitigMap< Unitig_data_t, Graph_data_t, is_const > , UnitigMapBase
- operator*() : neighborIterator< Unitig_data_t, Graph_data_t, is_const > , UnitigColors::UnitigColors_const_iterator , unitigIterator< Unitig_data_t, Graph_data_t, is_const >
- operator++() : neighborIterator< Unitig_data_t, Graph_data_t, is_const > , UnitigColors::UnitigColors_const_iterator , unitigIterator< Unitig_data_t, Graph_data_t, is_const >
- operator+=() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t >
- operator->() : neighborIterator< Unitig_data_t, Graph_data_t, is_const > , unitigIterator< Unitig_data_t, Graph_data_t, is_const >
- operator=() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , Kmer , UnitigColors , UnitigColors::UnitigColors_const_iterator
- operator==() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , Kmer , neighborIterator< Unitig_data_t, Graph_data_t, is_const > , UnitigColors::UnitigColors_const_iterator , unitigIterator< Unitig_data_t, Graph_data_t, is_const > , UnitigMap< Unitig_data_t, Graph_data_t, is_const > , UnitigMapBase
- optimizeFullColors() : UnitigColors

### - r -

- read() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , Kmer , UnitigColors
- referenceUnitigToString() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- remove() : CompactedDBG< Unitig_data_t, Graph_data_t > , UnitigColors
- rep() : Kmer

### - s -

- searchSequence() : CompactedDBG< Unitig_data_t, Graph_data_t >
- selfForwardBase() : Kmer
- serialize() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >
- set_deleted() : Kmer
- set_empty() : Kmer
- set_k() : Kmer
- setChar() : Kmer
- simplify() : CompactedDBG< Unitig_data_t, Graph_data_t >
- size() : CompactedDBG< Unitig_data_t, Graph_data_t > , UnitigColors

### - t -

- toString() : Kmer
- twin() : Kmer

### - u -

- UnitigColors() : UnitigColors
- UnitigColors_const_iterator() : UnitigColors::UnitigColors_const_iterator
- unitigIterator() : unitigIterator< Unitig_data_t, Graph_data_t, is_const >
- UnitigMap() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- UnitigMapBase() : UnitigMapBase

### - w -

- write() : ColoredCDBG< Unitig_data_t > , CompactedDBG< Unitig_data_t, Graph_data_t > , Kmer , UnitigColors

### - ~ -

- ~CompactedDBG() : CompactedDBG< Unitig_data_t, Graph_data_t >
- ~UnitigColors() : UnitigColors
- ~UnitigColors_const_iterator() : UnitigColors::UnitigColors_const_iterator